from tkinter import *

def cli():
	import time
	import datetime
	today = datetime.date.today()
	print("Welcome to Noty.You can now create sticky notes, easily.")
	time.sleep(1.5)
	x=input("Type your notes here: ")
	time.sleep(1)
	#time.sleep prevents GUI from popping up before it receives input.
	root = Tk()
	root.title("Noty")
	root.geometry("300x300")
	#changes the width and height of the GUI.
	Label(root, text=today).pack()
	#prints the current date.
	Label(root, text=x).pack()
	#prints the input.
	root.mainloop()
  





from setuptools import setup

setup(
    name = 'noty',
    packages=["noty"],
    version = '0.5.0',
    description = 'Creating sticky notes has never been easier',
    author = 'GrgBls',
    author_email = 'gmpalis6@gmail.com',
    url = 'https://github.com/GrgBls/noty', 
    py_modules=['noty'],
    install_requires=[
        
    ],
    entry_points='''
        [console_scripts]
        noty=noty.noty:cli
    ''',
)










